==> sdk-3.2.0-sources.jar: com/kontakt/sdk/android/cloud/api/executor/configs/ReadAllRequestExecutor.java <==
package com.kontakt.sdk.android.cloud.api.executor.configs;

import com.kontakt.sdk.android.cloud.CloudConstants;
import com.kontakt.sdk.android.cloud.api.ConfigsApi;
import com.kontakt.sdk.android.cloud.api.executor.PaginatedRequestExecutor;
import com.kontakt.sdk.android.cloud.api.service.ConfigsService;
import com.kontakt.sdk.android.cloud.response.paginated.Configs;
import com.kontakt.sdk.android.cloud.util.StringUtils;
import com.kontakt.sdk.android.common.Order;
import com.kontakt.sdk.android.common.model.OrderBy;
import com.kontakt.sdk.android.common.util.SDKPreconditions;
import java.util.List;
import java.util.Map;
import retrofit2.Call;

/**
 * Request executor provided by {@link ConfigsApi}. Use this class if you want to obtain
 * READ_ALL encrypted commands through fluent API in chained fashion. Here is an example of how to use this executor:
 * <pre>
 *   <code>
 *   IKontaktCloud kontaktCloud = KontaktCloud.newInstance();
 *   Configs configs = kontaktCloud.configs().readAll()
 *      .withIds("7HuT", "2Fge", "dFGh")
 *      .maxResult(10)
 *      .execute();
 *   </code>
 * </pre>
 */
public class ReadAllRequestExecutor extends PaginatedRequestExecutor<Configs> {

  private final ConfigsService configsService;

  private String[] uniqueIds;

  /**
   * Constructs request executor initialized with corresponding service class.
   * @param configsService the configs API service.
   */
  public ReadAllRequestExecutor(final ConfigsService configsService) {
    this.configsService = configsService;
  }

  /**
   * Specifies config unique IDs. Use that method if you want to fetch particular configs by ID.
   * @param uniqueIds config unique identifiers.
   * @return this request executor.
   */
  public ReadAllRequestExecutor withIds(final String... uniqueIds) {
    this.uniqueIds = SDKPreconditions.checkNotNull(uniqueIds, "IDs cannot be null");
    return this;
  }

  /**
   * Specifies config unique IDs. Use that method if you want to fetch particular configs by ID.
   * @param uniqueIds config unique identifiers.
   * @return this request executor.
   */
  public ReadAllRequestExecutor withIds(final List<String> uniqueIds) {
    SDKPreconditions.checkNotNull(uniqueIds, "IDs cannot be null");
    final int size = uniqueIds.size();
    this.uniqueIds = uniqueIds.toArray(new String[size]);
    return this;
  }

  /**
   * {@inheritDoc}
   */
  @Override public ReadAllRequestExecutor startIndex(int startIndex) {
    super.startIndex(startIndex);
    return this;
  }

  /**
   * {@inheritDoc}
   */
  @Override public ReadAllRequestExecutor maxResult(int maxResult) {
    super.maxResult(maxResult);
    return this;
  }

  /**
   * {@inheritDoc}
   */
  @Override public ReadAllRequestExecutor filter(String query) {
    super.filter(query);
    return this;
  }

  /**
   * {@inheritDoc}
   */
  @Override public ReadAllRequestExecutor orderBy(OrderBy orderBy, Order order) {
    super.orderBy(orderBy, order);
    return this;
  }

  /**
   * {@inheritDoc}
   */
  @Override public ReadAllRequestExecutor eTag(String eTag) {
    super.eTag(eTag);
    return this;
  }

  /**
   * {@inheritDoc}
   */
  @Override protected Call<Configs> prepareCall() {
    return configsService.getReadAllCommand(params());
  }

  /**
   * {@inheritDoc}
   */
  @Override protected Map<String, String> params() {
    final Map<String, String> params = super.params();
    if (uniqueIds != null && uniqueIds.length > 0) {
      params.put(CloudConstants.Common.UNIQUE_ID_PARAMETER, StringUtils.join(uniqueIds, ","));
    }
    return params;
  }
}

==> sdk-5.0.1-sources.jar: com/kontakt/sdk/android/cloud/api/executor/configs/ReadAllRequestExecutor.java <==
package com.kontakt.sdk.android.cloud.api.executor.configs;

import com.kontakt.sdk.android.cloud.CloudConstants;
import com.kontakt.sdk.android.cloud.api.ConfigsApi;
import com.kontakt.sdk.android.cloud.api.executor.PaginatedRequestExecutor;
import com.kontakt.sdk.android.cloud.api.service.ConfigsService;
import com.kontakt.sdk.android.cloud.response.paginated.Configs;
import com.kontakt.sdk.android.cloud.util.StringUtils;
import com.kontakt.sdk.android.common.Order;
import com.kontakt.sdk.android.common.model.OrderBy;
import com.kontakt.sdk.android.common.util.SDKPreconditions;
import java.util.List;
import java.util.Map;
import retrofit2.Call;

/**
 * Request executor provided by {@link ConfigsApi}. Use this class if you want to obtain
 * READ_ALL encrypted commands through fluent API in chained fashion. Here is an example of how to use this executor:
 * <pre>
 *   <code>
 *   KontaktCloud kontaktCloud = KontaktCloudFactory.create();
 *   Configs configs = kontaktCloud.configs().readAll()
 *      .withIds("7HuT", "2Fge", "dFGh")
 *      .maxResult(10)
 *      .execute();
 *   </code>
 * </pre>
 */
public class ReadAllRequestExecutor extends PaginatedRequestExecutor<Configs> {

  private final ConfigsService configsService;

  private String[] uniqueIds;

  /**
   * Constructs request executor initialized with corresponding service class.
   * @param configsService the configs API service.
   */
  public ReadAllRequestExecutor(final ConfigsService configsService) {
    this.configsService = configsService;
  }

  /**
   * Specifies config unique IDs. Use that method if you want to fetch particular configs by ID.
   * @param uniqueIds config unique identifiers.
   * @return this request executor.
   */
  public ReadAllRequestExecutor withIds(final String... uniqueIds) {
    this.uniqueIds = SDKPreconditions.checkNotNull(uniqueIds, "IDs cannot be null");
    return this;
  }

  /**
   * Specifies config unique IDs. Use that method if you want to fetch particular configs by ID.
   * @param uniqueIds config unique identifiers.
   * @return this request executor.
   */
  public ReadAllRequestExecutor withIds(final List<String> uniqueIds) {
    SDKPreconditions.checkNotNull(uniqueIds, "IDs cannot be null");
    final int size = uniqueIds.size();
    this.uniqueIds = uniqueIds.toArray(new String[size]);
    return this;
  }

  /**
   * {@inheritDoc}
   */
  @Override public ReadAllRequestExecutor startIndex(int startIndex) {
    super.startIndex(startIndex);
    return this;
  }

  /**
   * {@inheritDoc}
   */
  @Override public ReadAllRequestExecutor maxResult(int maxResult) {
    super.maxResult(maxResult);
    return this;
  }

  /**
   * {@inheritDoc}
   */
  @Override public ReadAllRequestExecutor filter(String query) {
    super.filter(query);
    return this;
  }

  /**
   * {@inheritDoc}
   */
  @Override public ReadAllRequestExecutor orderBy(OrderBy orderBy, Order order) {
    super.orderBy(orderBy, order);
    return this;
  }

  /**
   * {@inheritDoc}
   */
  @Override public ReadAllRequestExecutor eTag(String eTag) {
    super.eTag(eTag);
    return this;
  }

  /**
   * {@inheritDoc}
   */
  @Override protected Call<Configs> prepareCall() {
    return configsService.getReadAllCommand(params());
  }

  /**
   * {@inheritDoc}
   */
  @Override protected Map<String, String> params() {
    final Map<String, String> params = super.params();
    if (uniqueIds != null && uniqueIds.length > 0) {
      params.put(CloudConstants.Common.UNIQUE_ID_PARAMETER, StringUtils.join(uniqueIds, ","));
    }
    return params;
  }
}
